@@ -1,7 +1,8 @@
 from django import forms
-from widgets import PriceInput
 from prices import Price
 
+from .widgets import PriceInput
+
 __all__ = ('PriceField', 'PriceInput')
 
 
